Translate Toolkit 3.1.0
***********************

*Released on 21 September 2020*

This release contains improvements and bug fixes.


Changes
=======

Formats and Converters
----------------------

- YAML

  - Fix generating blank Ruby storage
  - Fix changing type of an unit
  - Preserve structured IDs on round trip
  - Several serialization fixes

- JSON

  - Preserve structured IDs on round trip
  - Several serialization fixes
    
- Android

  - Fix round trip of strings with newlines
  - Fix escaping double space with HTML

- CSV

  - Allow to control format autodetection

- XWiki

  - Added support for several XWiki formats

- RC

  - Fix parsing adjancent strings
  - Fix handling empty strings

- po2json

  - Never use empty translation in po2json

General
-------

- Added support for removing units from a storage
- Cleaned up storage index usage
- Updated several dependencies
- Dropped version control integration from storage
- Use LRU cache for imports to improve factory performance

Contributors
============

This release was made possible by the following people:

Michal Čihař, Simon Urli, wojtek555, Stuart Prescott,

And to all our bug finders and testers, a Very BIG Thank You.
